@@ -1,4 +1,3 @@
-from logging import raiseExceptions
 import numpy
 import pandas
 from grplot.features.optimizer.optimizer_key import optimizer_key
@@ -21,26 +20,33 @@ def optimizer_data(plot, df, x, y, hue, size, style, units, axes, mode):
     if len(key) > 0:
         # filter data
         if type(df) == dict:
-            if mode == 'numpy':
-                df_ = {}
-                for k in numpy.unique(key):
-                    if k in df.keys():
-                        if type(df[k]) == list:
+            df_ = {}
+            for k in numpy.unique(key):
+                if k in df.keys():
+                    if type(df[k]) == list:
+                        if mode in ['numpy','saver']:
                             df_[k] = numpy.array(df[k])
-                        elif type(df[k]) == numpy.ndarray:
-                            df_[k] = df[k]
+                        elif mode in ['pandas','perf']:
+                            df_ = pandas.DataFrame.from_dict({k: df[k] for k in numpy.unique(key) if k in df.keys()})
+                            break
                         else:
-                            raise Exception('Unsupported dictionary sub data structure!')
+                            raise Exception('Unknown optimizer argument!')
+                    elif type(df[k]) == numpy.ndarray:
+                        if mode in ['numpy','saver']:
+                            df_[k] = df[k]
+                        elif mode in ['pandas','perf']:
+                            df_ = pandas.DataFrame.from_dict({k: df[k] for k in numpy.unique(key) if k in df.keys()})
+                            break
+                        else:
+                            raise Exception('Unknown optimizer argument!')
                     else:
-                        pass
-            elif mode == 'pandas':
-                df_ = pandas.DataFrame.from_dict({k: df[k] for k in numpy.unique(key) if k in df.keys()})
-            else:
-                raise Exception('Unknown optimization mode!')
+                        raise Exception('Unsupported dictionary sub data structure!')
+                else:
+                    pass
         elif type(df) == pandas.core.frame.DataFrame:
-            if mode == 'numpy':
-                df_ = {k: df.to_records()[k]for k in numpy.unique(key) if k in df}
-            elif mode == 'pandas':
+            if mode in ['numpy','saver']:
+                df_ = {k: df[[k]].to_records()[k] for k in numpy.unique(key) if k in df}
+            elif mode in ['pandas','perf']:
                 df_ = df[[k for k in numpy.unique(key) if k in df]]
                 # if there is only one column
                 if type(df_) == pandas.core.series.Series:
@@ -48,7 +54,7 @@ def optimizer_data(plot, df, x, y, hue, size, style, units, axes, mode):
                 else:
                     pass
             else:
-                raise Exception('Unknown optimization mode!')
+                raise Exception('Unknown optimizer argument!')
         else:
             raise Exception('Unsupported data structure!')
     else:
